@@ -1,5 +1,5 @@
 package App::vaporcalc::Role::Calc;
-$App::vaporcalc::Role::Calc::VERSION = '0.003003';
+$App::vaporcalc::Role::Calc::VERSION = '0.003004';
 use Defaults::Modern
   -with_types => [ 'App::vaporcalc::Types' ];
 
@@ -74,7 +74,7 @@ method calc {
     sswitch ($ftype) {
       case 'PG': { $pg_ml -= $fml if $pg_ml }
       case 'VG': { $vg_ml -= $fml if $vg_ml }
-      default: { confess "Unknown flavor_type ", $self->flavor_type }
+      default: { confess "Unknown flavor_type $ftype" }
     }
   }
 
